@@ -27,6 +27,7 @@
 // Journal Entry
 
 #include "journalframe.h"
+#include "helper_p.h"
 
 #include <CalendarSupport/Utils>
 
@@ -47,7 +48,7 @@
 using namespace EventViews;
 
 JournalDateView::JournalDateView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent)
-    : QFrame(parent), mCalendar(calendar), mChanger(Q_NULLPTR)
+    : QFrame(parent), mCalendar(calendar), mChanger(nullptr)
 {
     auto layout = new QVBoxLayout(this);
     layout->setMargin(0);
@@ -109,7 +110,7 @@ Akonadi::Item::List JournalDateView::journals() const
 {
     Akonadi::Item::List l;
     l.reserve(mEntries.count());
-    Q_FOREACH (const JournalFrame *const i, mEntries) {
+    for (const JournalFrame *const i : qAsConst(mEntries)) {
         l.push_back(i->journal());
     }
     return l;
@@ -154,7 +155,7 @@ JournalFrame::JournalFrame(const Akonadi::Item &j,
 {
     mDirty = false;
     mWriteInProgress = false;
-    mChanger = Q_NULLPTR;
+    mChanger = nullptr;
 
     QVBoxLayout *verticalLayout = new QVBoxLayout(this);
 
